/***********************************************************************
 * This file is a basic template for creating C code for a PIC24F      *	
 * device.  Copy this file into your project directory and modify or   *
 * add to it as needed.                                                *  
 * Add the suitable linker script (e.g., p24FJ128GA010.gld) to the     *	
 * project.															   *
 *                                                                     *
 * If interrupts are not used, all code presented for that interrupt   *
 * can be removed or commented out with C-style comment declarations.  *
 *                                                                     *
 * For additional information about PIC24 architecture and language    *
 * tools, refer to the following documents:                            *
 *                                                                     *
 * MPLAB C30 Compiler User's Guide                        : DS51284    *
 * MPLAB ASM30, MPLAB LINK30 and Utilites User's Guide 	  : DS51317    *
 * 16-Bit Language Tools Libraries		          		  : DS51456    *
 * dsPIC Language Tools Getting Started                   : DS70094    *
 * dsPIC 30F Language Tools Quick Reference Card          : DS51322    *
 * Getting Started with dsPIC 30F DSC User's Guide        : DS70151    *
 *                                                                     *
 * Template file has been compiled with MPLAB C30 v3.01.               *
 *                                                                     *
 ***********************************************************************
 *                                                                     * 
 *    Author:                                                          *
 *    Company:                                                         * 
 *    Filename:       temp_128GA010.c                                  *	
 *    Date:           6/28/2007                                        *
 *    File Version:   2.0                                              *
 *    Other Files Required: p24FJ128GA010.gld			               *
 *    Tools Used: MPLAB IDE    -> 7.61                                 *
 *                C30 Compiler -> 3.01                                 *
 *                                                                     *
 *    Devices Supported:                                               *
 *                PIC24FJ128GA010                                      *	
 *                PIC24FJ96GA010                                       *
 *                PIC24FJ64GA010                                       *
 *                PIC24FJ128GA008                                      *
 *                PIC24FJ96GA008                                       *
 *                PIC24FJ64GA008                                       *
 *                PIC24FJ128GA006                                      *
 *                PIC24FJ96GA006                                       *
 *                PIC24FJ64GA006                                       *
 *                                                                     *
 ***********************************************************************
 *                                                                     *
 * Other Comments:                                                     *
 *                                                                     *
 * 1) C attributes, designated by the __attribute__ keyword, provide a *
 *    means to specify various characteristics of a variable or        *
 *    function, such as where a particular variable should be placed   *
 *    in memory, whether the variable should be aligned to a certain   *
 *    address boundary, whether a function is an Interrupt Service     *
 *    Routine (ISR), etc. If no special characteristics need to be     *
 *    specified for a variable or function, then attributes are not    *
 *    required. For more information about attributes, refer to the    *
 *    C30 User's Guide.                                                *
 *                                                                     *
 * 2) The __space__(data) and __space__(prog) attributes are used to   *	
 *    place a variable in data space and prog space, respectively.     *
 *                                                                     *
 * 3) The aligned(k) attribute, used in variable definitions, is used  *	
 *    to align a variable to the nearest higher 'k'-byte address       * 
 *    boundary. In most cases, variables are aligned either to avoid   *
 *    potential misaligned memory accesses.     		    		   *                           
 *                                                                     *
 * 4) The __interrupt__ attribute is used to qualify a function as an  *
 *    interrupt service routine. An interrupt routine can be further   *
 *    configured to save certain variables on the stack, using the     *
 *    __save__(var-list) directive.                                    *
 *                                                                     *
 * 5) The __shadow__ attribute is used to set up any function to       *  
 *    perform a fast context save using shadow registers.              *
 *                                                                     *
 * 6) Note the use of double-underscores (__) at the start and end of  *
 *    all the keywords mentioned above.                                *
 *                                                                     *
 **********************************************************************/

//Include the appropriate header (.h) file, depending on device used
//Example (for PIC24FJ128GA010): #include <p24FJ128GA010.h>          

#include <p24FJ128GA010.h>							


//Configuration Bit Macros to define device config registers.
//Device header file contains usage details

_CONFIG1(JTAGEN_OFF & GCP_OFF & GWRP_OFF & BKBUG_OFF & 
		 ICS_PGx2 & FWDTEN_OFF)

_CONFIG2(IESO_OFF & FCKSM_CSDCMD & OSCIOFNC_ON &  FNOSC_FRC & 
		 POSCMOD_NONE)


// Define constants here                            			     

#define CONSTANT1 10
#define CONSTANT2 20

/************* START OF GLOBAL DEFINITIONS ****************************/

//Define arrays: array1[], array2[], etc.          								    								
//Use the entire attribute OR with macro from header file            								
int __attribute__((space(data), aligned(32))) 
		ram_array[CONSTANT1];
					
int _BSS(32) ram_array2[CONSTANT1];

//Array without attributes                 								
int ram_array3[CONSTANT2];   //array3 is NOT an aligned buffer

//Program memory array
int __attribute__ ((space(prog))) 
		rom_array[] = {0x1, 0x2, 0x3, 0x4, 0x5};

//Program memory array using const
const int rom_array2[] = {0x6, 0x7, 0x8, 0x9, 0xA};


//Define global variables with attributes          								
int var1;// __attribute__((space(data)));

//near pointer to program memory
int *rom_ptr __attribute__ ((near));					

//Define global variables without attributes       									
int var2;
int *ram_ptr;

//Function prototype
void delay(void);  

/************** END OF GLOBAL DEFINITIONS *****************************/


/************* START OF MAIN FUNCTION *********************************/

int main ( void )
{
	
	//Add Code Here

}
/************* END OF MAIN FUNCTION ***********************************/



/****** START OF INTERRUPT SERVICE ROUTINES ***************************/
/* 
 * The names of various interrupt functions for     								
 * each device are defined in the linker script.    								
 */

//Interrupt Service Routine 1                      								
//No fast context save, and no variables stacked   		
void __attribute__((interrupt,no_auto_psv)) _ADC1Interrupt(void)
{

// Interrupt Service Routine code goes here      
}

//Interrupt Service Routine 2                   	
//Fast context save (using push.s and pop.s)      		
void __attribute__((interrupt, shadow,no_auto_psv)) _T1Interrupt(void)
{

//Interrupt Service Routine code goes here    
}

//Interrupt Service Routine 3: INT0Interrupt       	
//Save and restore variables var1, var2, etc.  
void __attribute__((interrupt(save(var1,var2)),no_auto_psv)) _INT0Interrupt(void)
{

//Interrupt Service Routine code goes here
}

/********* END OF INTERRUPT SERVICE ROUTINES **************************/
