/*****************************************************************************
 *
 * UART Demo for PIC24.
 *
 *****************************************************************************
 * FileName:        UART.c
 * Dependencies:    
 * Processor:       
 * Compiler:       	
 * Linker:          
 * Company:         Microchip Technology Incorporated
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") is intended and supplied to you, the Company's
 * customer, for use solely and exclusively with products manufactured
 * by the Company. 
 *
 * The software is owned by the Company and/or its supplier, and is 
 * protected under applicable copyright laws. All rights are reserved. 
 * Any use in violation of the foregoing restrictions may subject the 
 * user to criminal sanctions under applicable laws, as well as to 
 * civil liability for the breach of the terms and conditions of this 
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES, 
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT, 
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR 
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Vidyadhar		  30/June/06	     ...	
 * Brant Ivey			7/3/07		Updated for v4.0 of class
 *****************************************************************************/

#include <p24FJ128GA010.h>

_CONFIG1(JTAGEN_OFF & GCP_OFF & GWRP_OFF & BKBUG_OFF & ICS_PGx2 & FWDTEN_OFF)
_CONFIG2(IESO_OFF & FCKSM_CSDCMD & OSCIOFNC_ON &  FNOSC_PRI & POSCMOD_HS)

#define S3  PORTDbits.RD6

char RxByte, TxByte, Temp;

main()
{
	IOInit();				 //Initialize Switch and LED I/O

    UARTInit();              //Initialize the UART converter

	while(1)
	{
	
		if (!PORTDbits.RD13)
		{
			U2STA = U2STA^0x00C0;
			INTCON2bits.ALTIVT ^= 1;
			PORTAbits.RA7 ^= 1;
			while(!PORTDbits.RD13);
		}

	}
}




//To define UARTInit you may require some info.
// You will have to configure the registers:
// UxMODE, UxBRG, UxSTA
UARTInit()
{
	TRISFbits.TRISF5 = 0;

    //##########################################
    //  STEP 1:
	//	Load the count to get 300 baudrate
	//	BRG = Fcy/(16*BaudRate)-1  where Fcy = Fosc/2 = 4MHz
    //##########################################
    	
	U2BRG = 0x340;	                    // ###
	

    //##########################################
    //  STEP 2:
	// 	Flow Control Mode, No Loop-Back
	// 	No Auto-Baud, No Rx-Inversion
	//	Low BaudRate, 1 Stop-bit,
	//	8-bit with parity of your choice
    //##########################################
    	
	U2MODE = 0x8200;                    // ###
	

    //##########################################
    //  STEP 3:
	//	Tx Interrupt to interrupt when at least one location is free in Tx buffer
	//	No Tx Inversion, Disable Sync Break
	//	Enable Transmit, Disable Address Detect
	//	Interrupt on every receive. 
    //##########################################
    	
	U2STA = 0x0400;                     // ###


	IFS1bits.U2RXIF = 0;
	IEC1bits.U2RXIE = 1;

}


IOInit()
{
	TRISDbits.TRISD6 = 1;	//  PORTD<6> as input, SW3.
	TRISDbits.TRISD13 = 1;	//  PORTD<13> as input, SW4.

	AD1PCFG = 0xFFFF;
	TRISA = 0xFF00;	        // PORTA<7:0> as output for LED.
}



void _ISRFAST _U2RXInterrupt()
{
	__builtin_btg((unsigned int*)&LATA,0);

	IFS1bits.U2RXIF = 0;

	while(!U2STAbits.TRMT);
	U2TXREG = U2RXREG;

}

void _ISRFAST _AltU2RXInterrupt()
{
	__builtin_btg((unsigned int*)&LATA,0);

	IFS1bits.U2RXIF = 0;

	while(U2STAbits.URXDA)
	{
		while(U2STAbits.UTXBF);
		U2TXREG = U2RXREG;
	}

}





